--[[ $Id$
   Copyright (c) Brett England, 2013

   No commercial use.
   No redistribution at profit.
   All derivative work must retain this message and
   acknowledge the work of the original author.
--]]
local xap = require "xap"
local widget = require "widget" 
local storyboard = require "storyboard"

_W = display.viewableContentWidth
_H = display.viewableContentHeight

-- Setup GLOBAL xap_server variable
-- note: Establishing the object does not make any connections until the engine is started.
xap_server = xap.TCPServer{host="home.dbzoo.com", source="dbzoo.corona.demo", timeout=5}

-- Old style connection (still works)
--xap_server = xap.TCPServer("home.dbzoo.com")
--xap_server:setSource("dbzoo.corona.demo")

-- Wrap the engine:start()
function startXap()
	-- We can't start the engine show why and allow the user to quit.
	if not xap_server:start() then
		local options = {
							params = {
								title="xAP startup failure",
								msg=xap_server:getErrorMessage()								
							}
						}
		storyboard.gotoScene("fatalErrorScene", options)
		return false
	end	
	return true
end

function setupInterface()
	-- event listeners for tab buttons:
local function onFirstView( event )
	storyboard.gotoScene( "view1", {effect = "crossFade", time=200} )
end

local function onSecondView( event )
	storyboard.gotoScene( "rfsummary", {effect = "crossFade", time=200} )
end

local function onThirdView( event )
	storyboard.gotoScene( "tempsummary", {effect = "crossFade", time=200} )
end

local function onFourthView( event )
	storyboard.gotoScene( "powersummary", {effect = "crossFade", time=200} )
end

local function onFifthView( event )
	native.requestExit()
	return
end

-- table to set up buttons
local tabButtons = {
	{ label="Floorplan", 
	defaultFile = "icon1.png", 
	overFile = "icon1-down.png", 
	width = 32, 
	height = 32, 
	onPress=onFirstView, 
	selected=true },
 	
 	{ label="RF Summary", 
 	defaultFile = "icon2.png", 
 	overFile = "icon2-down.png", 
 	width = 32, 
 	height = 32, 
 	onPress=onSecondView },
 	
 	{ label="Temp Summary", 
 	defaultFile = "icon2.png", 
 	overFile = "icon2-down.png", 
 	width = 32, 
 	height = 32, 
 	onPress=onThirdView },
 	
 	{ label="Power Summary", 
 	defaultFile = "icon2.png", 
 	overFile = "icon2-down.png", 
 	width = 32, 
 	height = 32, 
 	onPress=onFourthView },
 	
 	{ label="Quit", 
 	defaultFile = "icon2.png", 
 	overFile = "icon2-down.png", 
 	width = 32, 
 	height = 32, 
 	onPress=onFifthView },
}

-- create the actual tabBar widget
local tabBar = widget.newTabBar{
	top = display.contentHeight - 50,	-- 50 is default height for tabBar widget
	buttons = tabButtons
}




onFirstView()	-- invoke first tab button's onPress event manually
end

-- Display stack trace on the screen if something bad happens
-- Searching the LOGS is too hard.
local unhandledErrorListener = function( event )
	local options = {
						params = {
						    fontSize=12,
							title="Unhandled Error",
							msg=event.errorMessage.."\n"..event.stackTrace,
							needQuitButton=false
						}
					}	
	storyboard.gotoScene("fatalErrorScene", options)
	return true  -- we handled this.
end
Runtime:addEventListener( "unhandledError", unhandledErrorListener )

-- Capture application events		
local onSystem = function( event )
    if event.type == "applicationExit" then
        xap_server:stop()
    elseif event.type == "applicationStart" then
	    if startXap() then
			setupInterface()
		end
	elseif event.type == "applicationSuspend" then
	   xap_server:stop()
	elseif event.type == "applicationResume" then
	   startXap()
    end
end
Runtime:addEventListener( "system", onSystem )


