--[[ $Id$
   Copyright (c) Brett England, 2013
   Copyright (c) Mark Baldwin, 2013

   No commercial use.
   No redistribution at profit.
   All derivative work must retain this message and
   acknowledge the work of the original author.
--]]



local xap = require "xap"
local widget = require "widget" 
local storyboard = require "storyboard"
local ui = require "ui"
local bsc = require "bsc"
local scene = storyboard.newScene()


function scene:createScene( event )
	local group = self.view
	local background = display.newImageRect( "background.png", 800, 480)
	background.x = display.contentWidth/2
	background.y = display.contentHeight/2 
	group:insert( background )
	
		-- UI helper functions
	function toggle(v, xpos, ypos)
		v.x = xpos
		v.y = ypos
		v.size = v.size or 20
		v.default = v.default or "glossy_button_red.png"
		v.on = v.on or "glossy_button_green.png"
		return bsc.newToggle(v)
	end

	function button(v, xpos, ypos)
			return bsc.newButton {
					defaultSrc = v.icon, defaultX = 80, defaultY = 80, -- img, width, height
					x=xpos, y=ypos, -- position
					size=20, -- font size
					offset=15,
					label={text=v.label, offset=-5, size=10, textColor={ 0, 0, 0, 255 }},
					textColor={ 0, 0, 0, 255 }, -- r,g,b,a
					xapSource=v.xapSource,
			}
	end

		-- A Label is a button that is does not accept user press events.
	function label(v, xpos, ypos)
			return bsc.newButton {
					defaultSrc = v.icon, defaultX = 80, defaultY = 80, -- img, width, height
					x=xpos, y=ypos, -- position
					size=20, -- font size
					offset=15,
					label={text=v.label, offset=-5, size=10, textColor={ 0, 0, 0, 255 }},
					textColor={ 0, 0, 0, 255 }, -- r,g,b,a
					xapSource=v.xapSource,
					readOnly=true
			}
	end


	local grid = {
	{
		  {c=ui.newLabel, bounds={0,0,800,100}, text="Power Usage Summary", align="center", size=30}
	},
--[[    	 
	{ -- ROW 1
		{},
		{c=label, icon="powerW.png", label="WholeHouse", xapSource='dbzoo.livebox.currentcost:ch.1'},
		{c=label, icon="powerW.png", label="Spare", xapSource='dbzoo.livebox.currentcost:sensor.1'},
		{c=label, icon="powerW.png", label="Computers", xapSource='dbzoo.livebox.currentcost:sensor.2'},
		{c=label, icon="powerW.png", label="HAH Hub", xapSource='dbzoo.livebox.currentcost:sensor.3'}		 
	},
	
	{ -- ROW 2
		{},
		{c=label, icon="powerW.png", label="Spare", xapSource='dbzoo.livebox.currentcost:sensor.4'},
		{c=label, icon="powerW.png", label="Spare", xapSource='dbzoo.livebox.currentcost:sensor.5'},
		{c=label, icon="powerW.png", label="Lounge TV", xapSource='dbzoo.livebox.currentcost:sensor.6'},
		{c=label, icon="powerW.png", label="Spare", xapSource='dbzoo.livebox.currentcost:sensor.7'}		 
	},
	
	{ -- ROW 3
		{},
		{},
		{c=label, icon="powerW.png", label="Spare", xapSource='dbzoo.livebox.currentcost:sensor.8'},
		{c=label, icon="powerW.png", label="Gas Pulse", xapSource='dbzoo.livebox.currentcost:sensor.9'},
		{},
		{}		 
	},]]--
	}
			
	-- Render grid
	local ypos = 0, xpos
	for _,r in ipairs(grid) do		
		xpos=200
		for _,v in pairs(r) do
			if v.c then
				group:insert(v.c(v, xpos, ypos)) --mod here
			end
			xpos = xpos + 80
		end
		ypos = ypos + 80
	end
	
end

-- Called immediately after scene has moved onscreen:
function scene:enterScene( event )
--storyboard.removeScene(storyboard.getPrevious())
end

-- Called when scene is about to move offscreen:
function scene:exitScene( event )
	local group = self.view
	storyboard.removeScene(storyboard.getCurrentSceneName())
	--display.remove(grid)	
end

-- If scene's view is removed, scene:destroyScene() will be called just prior to:
function scene:destroyScene( event )
	local group = self.view
	
	-- INSERT code here (e.g. remove listeners, remove widgets, save state variables, etc.)
	
end

-----------------------------------------------------------------------------------------
-- END OF YOUR IMPLEMENTATION
-----------------------------------------------------------------------------------------

-- "createScene" event is dispatched if scene's view does not exist
scene:addEventListener( "createScene", scene )

-- "enterScene" event is dispatched whenever scene transition has finished
scene:addEventListener( "enterScene", scene )

-- "exitScene" event is dispatched whenever before next scene's transition begins
scene:addEventListener( "exitScene", scene )

-- "destroyScene" event is dispatched before view is unloaded, which can be
-- automatically unloaded in low memory situations, or explicitly via a call to
-- storyboard.purgeScene() or storyboard.removeScene().
scene:addEventListener( "destroyScene", scene )

-----------------------------------------------------------------------------------------

return scene
